@@ -1,13 +1,13 @@
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Any, Dict, Generic, Optional, TypeVar, Union
+from typing import TYPE_CHECKING, Generic, Iterable, Optional, TypeVar
 
 from sila2.client.utils import call_rpc_function
 from sila2.framework.property.unobservable_property import UnobservableProperty
 
 if TYPE_CHECKING:
     from sila2.client.client_feature import ClientFeature
-    from sila2.client.client_metadata import ClientMetadata
+    from sila2.client.client_metadata import ClientMetadataInstance
 
 T = TypeVar("T")
 
@@ -20,7 +20,7 @@ class ClientUnobservableProperty(Generic[T]):
         self._parent_feature = parent_feature
         self._wrapped_property = wrapped_property
 
-    def get(self, *, metadata: Optional[Dict[Union[ClientMetadata, str], Any]] = None) -> T:
+    def get(self, *, metadata: Optional[Iterable[ClientMetadataInstance]] = None) -> T:
         param_msg = self._wrapped_property.get_parameters_message()
 
         response_msg = call_rpc_function(
