@@ -4,7 +4,7 @@ import datetime
 import uuid
 from concurrent.futures import Future
 from queue import Queue
-from typing import TYPE_CHECKING, Any, Callable, Iterable
+from typing import TYPE_CHECKING, Callable, Iterable
 
 from google.protobuf.message import Message
 
@@ -12,6 +12,10 @@ from sila2.framework.command.execution_info import CommandExecutionInfo, Command
 from sila2.framework.command.observable_command import ObservableCommand
 from sila2.framework.errors.command_execution_not_finished import CommandExecutionNotFinished
 from sila2.framework.fully_qualified_identifier import FullyQualifiedIdentifier
+from sila2.server.observables.observable_command_instance import (
+    ObservableCommandInstance,
+    ObservableCommandInstanceWithIntermediateResponses,
+)
 from sila2.server.observables.stream import Stream
 from sila2.server.observables.subscription_manager_thread import SubscriptionManagerThread
 
@@ -27,7 +31,7 @@ class ObservableCommandManager:
         self,
         parent_server: SilaServer,
         wrapped_command: ObservableCommand,
-        impl_func: Callable[[Queue[Any], Queue[CommandExecutionInfo]], Message],
+        impl_func: Callable[[ObservableCommandInstance], Message],
         metadata_identifiers: Iterable[FullyQualifiedIdentifier],
     ) -> None:
         self.parent_server = parent_server
@@ -45,8 +49,6 @@ class ObservableCommandManager:
         )
         self.info_subscription_thread.start()
 
-        func_kwargs = dict(execution_info_queue=self.execution_info_queue)
-
         if wrapped_command.intermediate_responses is not None:
             self.intermediate_response_subscription_thread = SubscriptionManagerThread(
                 self.wrapped_command.fully_qualified_identifier,
@@ -54,10 +56,13 @@ class ObservableCommandManager:
                 converter_func=wrapped_command.intermediate_responses.to_message,
             )
             self.intermediate_response_subscription_thread.start()
+            command_instance = ObservableCommandInstanceWithIntermediateResponses(
+                self.execution_info_queue, self.intermediate_response_queue
+            )
+        else:
+            command_instance = ObservableCommandInstance(self.execution_info_queue)
 
-            func_kwargs["intermediate_response_queue"] = self.intermediate_response_queue
-
-        self.result_future = parent_server.child_task_executor.submit(impl_func, **func_kwargs)
+        self.result_future = parent_server.child_task_executor.submit(impl_func, command_instance)
         self.result_future.add_done_callback(self.__after_execution)
 
     def subscribe_to_execution_infos(self) -> Stream[SilaExecutionInfo]:
