@@ -1,6 +1,5 @@
 from __future__ import annotations
 
-import logging
 import uuid
 from concurrent.futures import ThreadPoolExecutor
 from typing import TYPE_CHECKING, Dict, List, Optional, Union
@@ -23,13 +22,12 @@ from sila2.server.metadata_interceptor import MetadataInterceptor
 if TYPE_CHECKING:
     from sila2.framework.utils import HasFullyQualifiedIdentifier
 
-logger = logging.getLogger(__name__)
-
 
 class SilaServer:
     grpc_server: grpc.Server
     features: Dict[str, Feature]
     feature_servicers: Dict[str, FeatureImplementationServicer]
+    running: bool
 
     server_name: str
     server_type: str
@@ -58,6 +56,8 @@ class SilaServer:
         max_grpc_workers: int = 100,
         max_child_task_workers: int = 100,
     ):
+        self.running = False
+
         # import locally to prevent circular import
         from sila2.features.silaservice import SiLAServiceFeature
         from sila2.server.silaservice_impl import SiLAServiceImpl
@@ -155,8 +155,6 @@ class SilaServer:
         self.metadata_interceptors.append(interceptor)
 
     def start_insecure(self, address: str, port: int, enable_discovery: bool = True):
-        logger.info(f"Starting server {self.server_name} ({self.server_uuid}) on insecure {address}:{port}")
-
         for servicer in self.feature_servicers.values():
             servicer.implementation.start()
 
@@ -166,6 +164,7 @@ class SilaServer:
         if enable_discovery:
             info = self.service_broadcaster.register_server(self, address, port)
             self.running_instances.append(info)
+        self.running = True
 
     def stop(self, grace_period: Optional[float] = None):
         stop_event = self.grpc_server.stop(grace_period)
@@ -177,9 +176,14 @@ class SilaServer:
             servicer.implementation.stop()
         self.child_task_executor.shutdown(wait=True)
         stop_event.wait()
+        self.running = False
 
     def __getitem__(self, item: str) -> Feature:
         return self.features[item]
 
     def __del__(self):
-        self.stop()
+        try:
+            if self.running:
+                self.stop()
+        except AttributeError:  # when __init__ fails, some attributes might not exist yet, then they cannot be stopped
+            pass
